@@ -20,10 +20,12 @@ class Driver:
                  pool: 'DriverPool' = None,
                  change_proxy_on_each_request: bool = True,
                  proxies: tuple = (),
-                 install_adblock: bool = True):
+                 install_adblock: bool = True,
+                 anticaptcha_api_key: str = None):
         self.web_driver = ScrapyWebdriver(change_proxies_on_each_request=change_proxy_on_each_request,
                                           proxies=proxies,
-                                          install_adblock=install_adblock)
+                                          install_adblock=install_adblock,
+                                          anticaptcha_api_key=anticaptcha_api_key)
         self._blocked = False
         self.pool = pool
 
@@ -43,7 +45,8 @@ class DriverPool:
     def __init__(self, size=1,
                  change_proxy_on_each_request=True,
                  proxies=(),
-                 install_adblock=True):
+                 install_adblock=True,
+                 anticaptcha_api_key=None):
         self.size = size
         self.drivers = []
         self._waiting = []
